@@ -409,8 +409,7 @@ class CustomerProfile(Adapter):
         testing = options.profile.testing
         host    = ENDPOINT_XML_TEST if testing else ENDPOINT_XML_PRODUCTION
         
-        self.connection                         = urllib2.Request(url='https://' + host + REQUEST_PATH)
-        self.connection.headers['Content-Type'] = 'text/xml'
+        self.connection                         = urllib2.Request(url='https://' + host + REQUEST_PATH, headers={'Content-Type' : 'text/xml'})
     
     def create(self):
         """Create a CIM record."""
