@@ -39,21 +39,21 @@ class Serialize(object):
             billto = trans.billing
             
             if billto.firstname:
-                transaction['x_first_name'] = urllib.quote(billto.firstname)
+                transaction['x_first_name'] = urllib.quote(billto.firstname.encode("UTF-8"))
             if billto.lastname:
-                transaction['x_last_name']  = urllib.quote(billto.lastname)
+                transaction['x_last_name']  = urllib.quote(billto.lastname.encode("UTF-8"))
             if billto.company:
-                transaction['x_company']    = urllib.quote(billto.company)
+                transaction['x_company']    = urllib.quote(billto.company.encode("UTF-8"))
             if billto.address:
-                transaction['x_address']    = urllib.quote(billto.address)
+                transaction['x_address']    = urllib.quote(billto.address.encode("UTF-8"))
             if billto.city:
-                transaction['x_city']       = urllib.quote(billto.city)
+                transaction['x_city']       = urllib.quote(billto.city.encode("UTF-8"))
             if billto.state:
-                transaction['x_state']      = urllib.quote(billto.state)
+                transaction['x_state']      = urllib.quote(billto.state.encode("UTF-8"))
             if billto.postal_code:
                 transaction['x_zip']        = billto.postal_code
             if billto.country:
-                transaction['x_country']    = urllib.quote(billto.country)
+                transaction['x_country']    = urllib.quote(billto.country.encode("UTF-8"))
             if billto.phone:
                 transaction['x_phone']      = billto.phone
             if billto.fax:
@@ -64,21 +64,21 @@ class Serialize(object):
             shipto = trans.shipping
             
             if shipto.firstname:
-                transaction['x_ship_to_first_name'] = urllib.quote(shipto.firstname)
+                transaction['x_ship_to_first_name'] = urllib.quote(shipto.firstname.encode("UTF-8"))
             if shipto.lastname:
-                transaction['x_ship_to_last_name']  = urllib.quote(shipto.lastname)
+                transaction['x_ship_to_last_name']  = urllib.quote(shipto.lastname.encode("UTF-8"))
             if shipto.company:
-                transaction['x_ship_to_company']    = urllib.quote(shipto.company)
+                transaction['x_ship_to_company']    = urllib.quote(shipto.company.encode("UTF-8"))
             if shipto.address:
-                transaction['x_ship_to_address']    = urllib.quote(shipto.address)
+                transaction['x_ship_to_address']    = urllib.quote(shipto.address.encode("UTF-8"))
             if shipto.city:
-                transaction['x_ship_to_city']       = urllib.quote(shipto.city)
+                transaction['x_ship_to_city']       = urllib.quote(shipto.city.encode("UTF-8"))
             if shipto.state:
-                transaction['x_ship_to_state']      = urllib.quote(shipto.state)
+                transaction['x_ship_to_state']      = urllib.quote(shipto.state.encode("UTF-8"))
             if shipto.postal_code:
                 transaction['x_ship_to_zip']        = shipto.postal_code
             if shipto.country:
-                transaction['x_ship_to_country']    = urllib.quote(shipto.country)
+                transaction['x_ship_to_country']    = urllib.quote(shipto.country.encode("UTF-8"))
             if shipto.phone:
                 transaction['x_ship_to_phone']      = shipto.phone
             if shipto.fax:
